{ config, pkgs, ... }:

{
  imports =
    [
      ./common-headless.nix
    ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.device = "/dev/sdg"; # or "nodev" for efi only

  networking = {
    hostName = "vaccaria";
    hostId = "3d551a7c";
  };

  services.openssh.enable = true;

  users.extraUsers.gebner = {
    isNormalUser = true;
    extraGroups = ["wheel" "transmission"];
  };

  boot.supportedFilesystems = ["zfs"];
  boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages;

  system.stateVersion = "17.03";

  fileSystems."/mnt/vaccaria" = pkgs.lib.mkOverride 10 {
    device = "vaccaria/export";
    fsType = "zfs";
  };

 services.samba = {
   enable = true;
   extraConfig = ''
     passdb backend = tdbsam
     unix password sync = no
   '';
   shares = {
     export = {
       "guest ok" = "no";
       path = "/mnt/vaccaria";
     };
   };
 };

#  services.transmission = {
#    enable = true;
#    settings = {
#      download-dir = "/mnt/aplysia/torrents";
#      incomplete-dir = "/mnt/aplysia/torrents";
#    };
#  };

  networking.firewall = {
    allowedTCPPorts = [
      445 139 # samba
    ];
    allowedUDPPorts = [
      137 138 # samba
    ];
  };

  environment.systemPackages = with pkgs; [
    transmission
    samba
  ];

}
